Structs
- Nostr
Window Object - The
nostrobject is a global object that is injected by the Nostr client. It provides access to the Nostr protocol and its features. must be accessed through window.nostr. This object is available in the browser environment. - Nostr
Window Object Encryption